OiRA

Help

1. Voorbereiding
3. Inventarisatie + Evaluatie
4. Plan van aanpak
5. Rapport
6. Status 0%

# Rapportage

U heeft alle risico's van de organisatie geïnventariseerd en een plan van aanpak gemaakt. Nu kunt u een plan van aanpak maken waarin alle resultaten worden opgenomen. U kunt, als u dat wilt, extra tekst plaatsen in het vak dat hieronder staat. Die tekst wordt opgenomen aan het begin van het plan van aanpak.

Opslaan en verdergaan

Scroll to top
Back

## report.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More